function c=and_lu(a,b)
%       C=AND_LU(A,B) Lukasiewicz intersection of two fuzzy sets
%       A and B, defined as AND_LU(A,B) = max(Ax+Bx-1,0). Also called
%       bold intersection.
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A * B, where * is
%       max(Ax+Bx-1,0).
%
%       C = AND_LU(A) calculates intersection of all rows in A.
%
%       See also AND, AND_ZA, AND_PR, AND_RE.

% (c) Robert Babuska, March 1993

[am,an] = size(a);
if nargin == 1,
  c = max(sum(a)-am+1,0);
else
  [bm,bn] = size(b);
  if ( am > 1 & an == 1 & bn > 1 )
    a = a * ones(1,bn);
    if ( bm == 1 )
        b = ones(am,1) * b;
    end;
  end;

  c = max(a+b-1,0);
end;
