function c=and_pr(a,b)
%       C=AND_PR(A,B) The (probabilistic) intersection (product) of two
%       fuzzy sets A and B defined as AND_PR(A,B) = Ax*Bx.
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A * B, where * is Ax*Bx.
%
%       C = AND_PR(A) calculates intersection of all rows in A.
%
%       See also AND, AND_ZA, AND_LU, AND_RE.

% Fuzzy Toolbox function
% (c) Robert Babuska, March 1993

if nargin == 1,
  c = prod(a);
else
  [am,an] = size(a);
  [bm,bn] = size(b);
  if ( am > 1 & an == 1 & bn > 1 )
    a = a * ones(1,bn);
    if ( bm == 1 )
        b = ones(am,1) * b;
    end;
  end;
  c = a.*b;
end;
