function v = center(x,f)
% CENTER calculates centers of fuzzy clusters. Used by FISODATA.
%
% V = CENTER(X,F)
%    Input:
%       X ... M by N data matrix, M number of data points
%             and N the dimension of X
%       F ... M by C fuzzy partition matrix, M number of data points
%             and C number of clusters
%    Output:
%       V ... C by N cluster center matrix, C number of clusters
%             and N the data vector dimension

% (c) Robert Babuska, June 1993

[mx,nx] = size(x);
[mf,nf] = size(f);

if (nx == 1)
  v = (sum(x*ones(1,nf).*f) ./ sum(f))';
else
  v = zeros(nf,nx);
  for i = 1 : nx
      v(:,i) = (sum(x(:,i)*ones(1,nf).*f) ./ sum(f))';
  end;
end;

