function z0=coaw(z,C,w,i);
% COAW Weighted center-of-area defuzzification.
%
% COA(Z,C) calculates the center of area of the fuzzy set C on universe Z.
%
% COW(Z,C,W) calculates the weighted center of area of the fuzzy set C on
%       universe Z. When C contains singletons, weighted fuzzy mean is
%       calculated.
%
% See also COA, MOM.

% (c) Robert Babuska, March 1993

z = z(:); C = C(:);
if (nargin >= 3)                % weight supplied
  if isempty(w) w = ones(1,length(C(:,1))); end;
  w = w(:);
  C = C.*w;                     % multiply by weights
end;
if any(max(C))
  z0 = (sum(z.*C)./sum(C))';    % calculate COA
else 
  z0 = 0;
end;

