% Fuzzy Toolbox for MATLAB
% Version 3.1   April 1998
% Copyright (c) 1992-98 Robert Babuska
%
% Fuzzy sets - basic definitions
%   acut       - Alpha-cut
%   acuts      - Strong alpha-cut
%   alevel     - Alpha-level
%   card       - Scalar and relative cardinality
%   crossovr   - Crossover point
%   ker        - Fuzzy set kernel
%   hgt        - Fuzzy set height
%   supp       - Fuzzy set support
%   normal     - Fuzzy set normalization
%   mgrade     - Calculates membership grade (both for parametric and
%                point-wise membership functions)
%   mfplot     - Plot the membership functions
%
% Operations with fuzzy sets
%   and_lu     - Conjunction of two fuzzy sets - Lukasiewicz
%   and_pr     - Conjunction of two fuzzy sets - probability
%   and_re     - Conjunction of two fuzzy sets - restricted
%   and_za     - Conjunction of two fuzzy sets - Zadeh
%   or_lu      - Disjunction of two fuzzy sets - Lukasiewicz
%   or_pr      - Disjunction of two fuzzy sets - probability
%   or_re      - Disjunction of two fuzzy sets - restricted
%   or_za      - Disjunction of two fuzzy sets - Zadeh
%   sdif       - Symmetrical difference of two fuzzy sets
%   csum       - Convex linear sum of min and max of two fuzzy sets
%   not_za     - Complement according to Zadeh
%   not_su     - Complement according to Sugeno
%   not_ya     - Complement according to Yager
%   gendist    - Generalized distance function
%   gencrit    - Generalized criterion function
%
% Fuzzy implications
%   impl_ex    - Extended propositional calculus implication
%   impl_ma    - Material implication
%   impl_pr    - Propositional calculus
%   impl_bg    - Brouwer-Godel's implication
%   impl_go    - Goguen's implication
%   impl_kd    - Kleene-Dienes' implication
%   impl_la    - Larsen's implication
%   impl_lu    - Lukasiewicz implication
%   impl_md    - Mamdani's implication
%   impl_re    - Reichenbach's implication
%   impl_rs    - Rescher's implication
%   impl_wi    - Willmott's implication
%
% Triangular norms and co-norms
%   tnorm      - Triangle norm with type as a parameter
%   t_do       - Triangle norm - Dombi
%   t_du       - Triangle norm - Dubois & Prade
%   t_fr       - Triangle norm - Frank
%   t_ha       - Triangle norm - Hamacher
%   t_la       - Triangle norm - lambda
%   t_sk       - Triangle norm - Schweizer & Sklar
%   t_ya       - Triangle norm - Yager
%   snorm      - Triangle co-norm with type as a parameter
%   s_do       - Triangle co-norm - Dombi
%   s_du       - Triangle co-norm - Dubois & Prade
%   s_fr       - Triangle co-norm - Frank
%   s_ha       - Triangle co-norm - Hamacher
%   s_la       - Triangle co-norm - lambda
%   s_sk       - Triangle co-norm - Schweizer & Sklar
%   s_ya       - Triangle co-norm - Yager
%
% Composition of fuzzy relations
%   sup_min    - Sup-min composition
%   sup_prod   - Sup-product composition
%
% Linguistic hedges
%   conc       - Concentration operator
%   dil        - Dilation operator
%   ext        - Extensification
%   intsf      - Intensification
%   normal     - Fuzzy set normalization
%   power      - General power
%   highly     - Linguistic hedge highly
%   moreless   - Linguistic hedge more or less
%   minus      - Linguistic hedge minus
%   plush      - Linguistic hedge plus
%   rather     - Linguistic hedge rather
%   roughly    - Linguistic hedge roughly
%   slightly   - Linguistic hedge slightly
%   very       - Linguistic hedge very
%
% Defuzzification methods
%   area       - Fuzzy set area
%   coa        - Center of area (gravity) defuzzification
%   coaw       - Weighted singleton center of area defuzzification
%   mom        - Mean of maxima defuzzification
%
% Fuzzy control and modeling
%   dofmin     - Degree of fulfillment, conjunction calculated as minimum
%   dofprod    - Degree of fulfillment, conjunction calculated as product
%   doftn      - Degree of fulfillment, user-supplied t-norm
%   infer      - Mamdani's inference
%   txt2rls    - Rule-base parser, converts text form to matrix form
%   rls2txt    - Converts rule-base in matrix form to text form
%   sample.rb  - Sample rule-base
%   suglms     - Least squares solution for linear Sugeno's fuzzy model
%   sugval     - Sugeno's fuzzy inference
%
% Fuzzy clustering
%   fisodata   - Fuzzy ISODATA clustering algorithm
%   fisofast   - A faster (les general) version of fuzzy ISODATA
%   dist       - Distance function (data from cluster prototypes)
%   center     - Calculates cluster centers
%
% Utility functions
%   rbfull     - Generates a rule-base with all combinations of premise variables
%   regres     - Makes a regression matrix
%   mfequ      - Generates equidistant symmetrical membership functions
%   mfset      - Setup membership functions editor
%   mfget      - Read membership functions parameters from the editor

