function [ret,x0,str,ts,xts]=demblock(t,x,u,flag);
%DEMBLOCK	is the M-file description of the SIMULINK system named DEMBLOCK.
%	DEMBLOCK has a the following characteristics:
%		0 continuous states
%		31 discrete states
%		0 outputs
%		0 inputs
%		does not have direct feedthrough
%		1 sample times
%
%	The block-diagram can be displayed by typing: DEMBLOCK.
%
%	SYS=DEMBLOCK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEMBLOCK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEMBLOCK with a FLAG of zero:
%	[SIZES]=DEMBLOCK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,292,611,467])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'tmax')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', 'tmax/200')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Signal Generator',[sys,'/','Signal Gen.'])
set_param([sys,'/','Signal Gen.'],...
		'orientation',2,...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','3.000000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads',...
		'position',[45,103,90,137])

add_block('built-in/S-Function',[sys,'/','S-function1'])
set_param([sys,'/','S-function1'],...
		'hide name',0,...
		'Font Name','Times New Roman',...
		'Font Size',8,...
		'function name','sfunimpl',...
		'parameters','figno, fs, domain, impl, par',...
		'Mask Display','FUZZY IMPLICATION')
set_param([sys,'/','S-function1'],...
		'Mask Type','Implication',...
		'Mask Dialogue','Implication|Figure (0 for no online plot):|Output fuzzy sets: |Domain: |Implication operator: |Implication parameter:')
set_param([sys,'/','S-function1'],...
		'Mask Translate','figno = @1; fs = @2; domain = @3; impl = @4; par = @5;',...
		'Mask Entries','2\/mgrade(domout,mfout)\/domout\/impl\/implpar\/',...
		'position',[150,19,280,71])

add_block('built-in/S-Function',[sys,'/','S-function2'])
set_param([sys,'/','S-function2'],...
		'hide name',0,...
		'Font Name','Times New Roman',...
		'Font Size',8,...
		'function name','sfunagr',...
		'parameters','figno, nsets, domain, agr, par',...
		'Mask Display','AGGREGATION')
set_param([sys,'/','S-function2'],...
		'Mask Type','Agregation',...
		'Mask Dialogue','Aggregation|Figure (0 for no online plot): |Number of fuzzy sets:|Domain: |Aggregation operator: |Aggregation parameter:')
set_param([sys,'/','S-function2'],...
		'Mask Translate','figno = @1; nsets = @2; domain = @3; agr = @4; par = @5;',...
		'Mask Entries','3\/size(mfout,1)\/domout\/aggr\/agrpar\/',...
		'position',[315,18,425,72])

add_block('built-in/S-Function',[sys,'/','S-function3'])
set_param([sys,'/','S-function3'],...
		'hide name',0,...
		'Font Name','Times New Roman',...
		'Font Size',8,...
		'function name','sfundef',...
		'parameters','figno,domain, def, par1, par2',...
		'Mask Display','DEFUZIFICATION')
set_param([sys,'/','S-function3'],...
		'Mask Type','Defuzzification',...
		'Mask Dialogue','Dufuzzification|Figure (0 for no online plot): |Domain: |Defuzzification operator: |Parameter1:|Parameter2:')
set_param([sys,'/','S-function3'],...
		'Mask Translate','figno = @1; domain = @2; def = @3; par1 = @4; par2 = @5;',...
		'Mask Entries','4\/domout\/defuz\/defuzpar1\/defuzpar2\/',...
		'position',[450,19,560,71])

add_block('built-in/S-Function',[sys,'/','Fuzzification'])
set_param([sys,'/','Fuzzification'],...
		'hide name',0,...
		'Font Name','Times New Roman',...
		'Font Size',8,...
		'function name','sfunfuzz',...
		'parameters','figno,mfs,rdom,idom',...
		'Mask Display','FUZZIFICATION')
set_param([sys,'/','Fuzzification'],...
		'Mask Type','Fuzzification',...
		'Mask Dialogue','Fuzzification|Figure (0 for no online plot): |Membership functions matrix:|Reference domain ([] for continuous): |Input domain([] for crisp input):')
set_param([sys,'/','Fuzzification'],...
		'Mask Translate','figno = @1; mfs = @2; rdom = @3; idom = @4;',...
		'Mask Help','Calculates membership degrees of an input into the specified fuzzy sets.',...
		'Mask Entries','1\/mfinp\/[]\/[]\/')
set_param([sys,'/','Fuzzification'],...
		'position',[25,17,130,73])


%     Subsystem  'Input - red'.

new_system([sys,'/','Input - red'])
set_param([sys,'/','Input - red'],'Location',[4,68,278,261])

add_block('built-in/Inport',[sys,'/','Input - red/x'])
set_param([sys,'/','Input - red/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Input - red/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Input - red/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])
add_line([sys,'/','Input - red'],[90,65;125,65])
set_param([sys,'/','Input - red'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Input - red'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','Input - red'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','Input - red'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.')
set_param([sys,'/','Input - red'],...
		'Mask Entries','5\/tmax\/min(dominp)\/max(dominp)\/''r-''\/')


%     Finished composite block 'Input - red'.

set_param([sys,'/','Input - red'],...
		'Drop Shadow',4,...
		'position',[130,93,180,137])


%     Subsystem  'Output - cyan'.

new_system([sys,'/','Output - cyan'])
set_param([sys,'/','Output - cyan'],'Location',[4,68,278,261])

add_block('built-in/S-Function',[sys,'/',['Output - cyan/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Output - cyan/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Output - cyan/x'])
set_param([sys,'/','Output - cyan/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Output - cyan'],[90,65;125,65])
set_param([sys,'/','Output - cyan'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Output - cyan'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','Output - cyan'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','Output - cyan'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.')
set_param([sys,'/','Output - cyan'],...
		'Mask Entries','5\/tmax\/min(domout)\/max(domout)\/''c-''\/')


%     Finished composite block 'Output - cyan'.

set_param([sys,'/','Output - cyan'],...
		'orientation',2,...
		'Drop Shadow',4,...
		'position',[475,88,525,132])


%     Subsystem  'GScope2'.

new_system([sys,'/','GScope2'])
set_param([sys,'/','GScope2'],'Location',[4,85,278,278])

add_block('built-in/S-Function',[sys,'/',['GScope2/S-function',13,'M-file which ',13,'pauses']])
set_param([sys,'/',['GScope2/S-function',13,'M-file which ',13,'pauses']],...
		'function name','sfunpaus',...
		'parameters','sec',...
		'position',[130,55,180,75])

add_block('built-in/Constant',[sys,'/','GScope2/Constant'])
set_param([sys,'/','GScope2/Constant'],...
		'Value','0',...
		'position',[50,55,70,75])
add_line([sys,'/','GScope2'],[75,65;125,65])
set_param([sys,'/','GScope2'],...
		'Mask Display','PAUSE',...
		'Mask Type','Pause',...
		'Mask Dialogue','Pause|Pause for second(s):',...
		'Mask Translate','sec  = @1;',...
		'Mask Entries','[]\/')


%     Finished composite block 'GScope2'.

set_param([sys,'/','GScope2'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[255,99,390,130])
add_line(sys,[285,45;310,45])
add_line(sys,[430,45;445,45])
add_line(sys,[565,45;580,45;580,110;530,110])
add_line(sys,[135,45;145,45])
add_line(sys,[40,120;5,120;5,45;20,45])
add_line(sys,[5,90;100,90;100,115;125,115])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
