function [ret,x0,str,ts,xts]=relation(t,x,u,flag);
%RELATION	is the M-file description of the SIMULINK system named RELATION.
%	The block-diagram can be displayed by typing: RELATION.
%
%	SYS=RELATION(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes RELATION to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling RELATION with a FLAG of zero:
%	[SIZES]=RELATION([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[335,449,859,619])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '1')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '130')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Discrete State-Space',[sys,'/','N-dimensional delay'])
set_param([sys,'/','N-dimensional delay'],...
		'orientation',2,...
		'A','zeros(dim)',...
		'B','eye(dim)',...
		'C','eye(dim)',...
		'D','zeros(dim)',...
		'X0','init',...
		'Sample time','tsamp',...
		'Mask Display','Unit delay')
set_param([sys,'/','N-dimensional delay'],...
		'Mask Type','N-dim delay',...
		'Mask Dialogue','Delay|Vector dimesion:|Initial condition:|Sample time:',...
		'Mask Translate','dim = @1; init = @2; tsamp = @3;',...
		'Mask Help','Help')
set_param([sys,'/','N-dimensional delay'],...
		'Mask Entries','length(domout)\/ainp(size(ainp,1),:)\/1/30\/',...
		'position',[155,15,255,45])

add_block('built-in/S-Function',[sys,'/','MAX-MIN composition'])
set_param([sys,'/','MAX-MIN composition'],...
		'Font Name','Times New Roman',...
		'function name','sfunrel',...
		'parameters','R',...
		'Mask Display','MAX-MIN',...
		'Mask Type','Composition')
set_param([sys,'/','MAX-MIN composition'],...
		'Mask Dialogue','Relational composition|Fuzzy relation:',...
		'Mask Translate','R = @1;',...
		'Mask Help','Calculates MAX-MIN relational composition.',...
		'Mask Entries','R\/')
set_param([sys,'/','MAX-MIN composition'],...
		'position',[155,74,240,116])


%     Subsystem  'FScope'.

new_system([sys,'/','FScope'])
set_param([sys,'/','FScope'],'Location',[4,68,278,261])

add_block('built-in/S-Function',[sys,'/',['FScope/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['FScope/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunfset',...
		'parameters','figno,nsets,domain,color',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','FScope/x'])
set_param([sys,'/','FScope/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','FScope'],[90,65;125,65])
set_param([sys,'/','FScope'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Fuzzy scope.')
set_param([sys,'/','FScope'],...
		'Mask Dialogue','Bar graph scope using MATLAB graph window.\nEnter number of bars and line type.|Figure:|Number fuzzy sets:|domain:|Line type (rgbw-:*):')
set_param([sys,'/','FScope'],...
		'Mask Translate','figno = @1; nsets = @2; domain = @3; color = @4; ',...
		'Mask Help','This block plots fuzzy set(s) to the MATLAB graph window. Look at the m-file sfunfset.m to see how it works.')
set_param([sys,'/','FScope'],...
		'Mask Entries','2\/1\/domout\/''g''\/')


%     Finished composite block 'FScope'.

set_param([sys,'/','FScope'],...
		'Drop Shadow',4,...
		'position',[300,76,330,114])

add_block('built-in/S-Function',[sys,'/','S-function4'])
set_param([sys,'/','S-function4'],...
		'hide name',0,...
		'Font Name','Times New Roman',...
		'function name','sfundef',...
		'parameters','figno,domain, def, par1, par2',...
		'Mask Display','DEFUZIFICATION',...
		'Mask Type','Defuzzification')
set_param([sys,'/','S-function4'],...
		'Mask Dialogue','Dufuzzification|Figure (0 for no online plot): |Domain: |Defuzzification operator: |Parameter1:|Parameter2:',...
		'Mask Translate','figno = @1; domain = @2; def = @3; par1 = @4; par2 = @5;')
set_param([sys,'/','S-function4'],...
		'Mask Entries','3\/domout\/''mom''\/[]\/[]\/',...
		'position',[320,10,460,50])


%     Subsystem  'Output - cyan'.

new_system([sys,'/','Output - cyan'])
set_param([sys,'/','Output - cyan'],'Location',[4,68,278,261])

add_block('built-in/Inport',[sys,'/','Output - cyan/x'])
set_param([sys,'/','Output - cyan/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Output - cyan/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Output - cyan/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])
add_line([sys,'/','Output - cyan'],[90,65;125,65])
set_param([sys,'/','Output - cyan'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Output - cyan'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','Output - cyan'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','Output - cyan'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.')
set_param([sys,'/','Output - cyan'],...
		'Mask Entries','4\/1\/min(domout)\/max(domout)\/''c-''\/')


%     Finished composite block 'Output - cyan'.

set_param([sys,'/','Output - cyan'],...
		'orientation',2,...
		'Drop Shadow',4,...
		'position',[385,74,425,116])


%     Subsystem  'FScope '.

new_system([sys,'/','FScope '])
set_param([sys,'/','FScope '],'Location',[4,68,278,261])

add_block('built-in/S-Function',[sys,'/',['FScope /S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['FScope /S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunfset',...
		'parameters','figno,nsets,domain,color',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','FScope /x'])
set_param([sys,'/','FScope /x'],...
		'position',[65,55,85,75])
add_line([sys,'/','FScope '],[90,65;125,65])
set_param([sys,'/','FScope '],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Fuzzy scope.')
set_param([sys,'/','FScope '],...
		'Mask Dialogue','Bar graph scope using MATLAB graph window.\nEnter number of bars and line type.|Figure:|Number fuzzy sets:|domain:|Line type (rgbw-:*):')
set_param([sys,'/','FScope '],...
		'Mask Translate','figno = @1; nsets = @2; domain = @3; color = @4; ',...
		'Mask Help','This block plots fuzzy set(s) to the MATLAB graph window. Look at the m-file sfunfset.m to see how it works.')
set_param([sys,'/','FScope '],...
		'Mask Entries','1\/1\/domout\/''g''\/')


%     Finished composite block 'FScope '.

set_param([sys,'/','FScope '],...
		'orientation',2,...
		'Drop Shadow',4,...
		'position',[35,11,65,49])


%     Subsystem  'GScope2'.

new_system([sys,'/','GScope2'])
set_param([sys,'/','GScope2'],'Location',[4,85,278,278])

add_block('built-in/Constant',[sys,'/','GScope2/Constant'])
set_param([sys,'/','GScope2/Constant'],...
		'Value','0',...
		'position',[50,55,70,75])

add_block('built-in/S-Function',[sys,'/',['GScope2/S-function',13,'M-file which ',13,'pauses']])
set_param([sys,'/',['GScope2/S-function',13,'M-file which ',13,'pauses']],...
		'function name','sfunpaus',...
		'parameters','sec',...
		'position',[130,55,180,75])
add_line([sys,'/','GScope2'],[75,65;125,65])
set_param([sys,'/','GScope2'],...
		'Mask Display','PAUSE',...
		'Mask Type','Pause',...
		'Mask Dialogue','Pause|Pause for second(s):',...
		'Mask Translate','sec  = @1;',...
		'Mask Entries','0\/')


%     Finished composite block 'GScope2'.

set_param([sys,'/','GScope2'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[16,104,95,141])
add_line(sys,[245,95;295,95])
add_line(sys,[465,30;475,30;475,95;430,95])
add_line(sys,[150,30;110,30;110,95;150,95])
add_line(sys,[275,95;275,30;260,30])
add_line(sys,[275,30;315,30])
add_line(sys,[110,30;70,30])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
