function  [sys, x0]  = sfunagr(t,x,u,flag,figno,nsets,domain,agr,par)
% SFUNAGR an S-function which aggregates fuzzy sets
%
%       This M-file is designed to be used in a SIMULINK S-function block.
%	
%       The input arguments are
%       figno:          Figure number (0 for no on-line plot).
%       nsets:          Number of input fuzzy sets.
%       domain:         Output domain (used for on-line plots)
%       agr:            Aggregation operator function (if [], default
%                       MAX is used).
%       par:            Additional parameter ([] for non-parametric
%                       operators).

% (c) Robert Babuska, December 1993

if abs(flag) == 2       % state

        sys = x;

elseif flag == 3        % output
  npoints = length(domain);
  fs = zeros(nsets,npoints);
  fs(:) = u;
  if length(agr) == 0,
      sys = max(fs);
  elseif length(par) == 0,
      sys = feval(agr,fs);
  else
      sys = feval(impl,fs,par);
  end;
  if figno ~= 0,
    ss = sys;
    if nsets == npoints,        % singletons
      npoints = 3*npoints;
      fss = fs; fs = zeros(nsets,npoints);
      fs(:,2:3:npoints) = fss;
      ss = zeros(1,npoints);
      ss(2:3:npoints) = sys;
    end;
    for i = 1 : nsets,
      set(x(i),'ydata',fs(i,:));
    end;
    set(x(nsets+1),'ydata',ss);
  end;

elseif flag  == 0, 
  npoints = length(domain);
  % [cont, discr, outputs, inputs, roots, feedthrough]
  sys = [0, nsets+1, npoints, nsets*npoints, 0, 1];
  x0 = zeros(nsets+1,1);
  if figno ~= 0,
        while ~any(get(0,'Children')==figno),
          figure('Visible','off');
        end
        set(figno,'Visible','off');
        oldfig = get(0,'CurrentFigure');

        set(0,'CurrentFigure',figno);
        clf;
        hold on;
        if nsets == npoints,    % singletons
          domain = ones(3,1)*domain; domain = domain(:)';
          x0 = plot(domain,zeros(nsets,3*npoints),'EraseMode','normal');
          x0 = [x0; ...
               plot(domain,zeros(1,3*npoints),'w','EraseMode','xor',...
               'LineWidth',5)];
        else
          x0 = plot(domain,zeros(nsets,npoints),'EraseMode','normal');
          x0 = [x0; ...
               plot(domain,zeros(1,npoints),'w','EraseMode','xor',...
               'LineWidth',3)];
        end;
        axis([min(domain) max(domain) 0 1]);
        hold off;
        set(figno,'BackingStore','off','Visible','on')
        set(0,'CurrentFigure',oldfig);
  end;
else
    sys = [];
end

