function  [sys, x0]  = sfunfuzz(t,x,u,flag,figno,mfs,rdom,idom)
% SFUNFUZZ an S-function which performs fuzzification of a crisp or
%          fuzzy input.
%
%       This M-file is designed to be used in a SIMULINK S-function block.
%       Uses Fuzzy Toolbox function MGRADE.
%	
%       The input arguments are
%       figno:          Figure number (0 for no on-line plot).
%       mfs:            Membership functions
%       rdom:           Domain of reference fuzzy sets.
%       idom:           Domain for fuzzy input.

% (c) Robert Babuska, December 1993

if abs(flag) == 2                       % state
   sys = x;

elseif flag == 3                        % output
  lidom = length(idom);
  nsets = size(mfs,1);
  if lidom > 0,
    mfref = mgrade(idom,mfs,rdom);
    sys = max(min(ones(nsets,1)*u',mfref)');
  else
    sys = mgrade(u',mfs,rdom);
  end;
  if figno ~= 0,
    maxd = max(mfs(:,size(mfs,2)));
    if lidom > 0,
      ii = min(idom);
      set(x(1),'ydata',u);
      for i = 1 : length(sys),
        ii = max(idom(sys(i)==mfref(i,:) | sys(i) == u'));
        set(x(1+i),'xdata',[ii maxd],'ydata',[sys(i) sys(i)]);
      end;
    else
      set(x(1),'xdata',[u u]);
      for i = 1 : length(sys),
        set(x(1+i),'xdata',[u max(mfs(:,size(mfs,2)))],'ydata',[sys(i) sys(i)]);
      end;
    end;
  end;

elseif flag  == 0,
  nsets = size(mfs,1);
  lidom = length(idom);
  if lidom == 0, ninps = 1; else ninps = lidom; end;
  % [cont, discr, outputs, inputs, roots, feedthrough]
  sys = [0, nsets+1, nsets, ninps, 0, 1];
  x0 = 0;
  if figno ~= 0,
        npoints = length(rdom);
        if npoints == 0,
           dmin = min(mfs(:,2));
           dmax = max(mfs(:,5));
           dom = dmin:(dmax-dmin)/100:dmax;
        else
           dom = rdom;
        end;
        while ~any(get(0,'Children')==figno),
           figure('Visible','off');
        end
        set(figno,'Visible','off');
        oldfig = get(0,'CurrentFigure');
        set(0,'CurrentFigure',figno);
        clf;
        hold on;
        if npoints == 0,
          mfs = mgrade(dom,mfs);
        end
        plot(dom,mfs);
        if lidom > 0,
          x0 = plot(idom,zeros(size(idom)),'w','LineWidth',2,'EraseMode','xor');
        else
          x0 = plot([0 0],[0 1],'w','LineWidth',2,'EraseMode','xor');
  	end;
        x0 = [x0;plot([0 0],zeros(2,nsets),'--','Erasemode','xor')];
        axis([min(dom) max(dom) 0 1]);
        hold off;
        set(gca,'Box','on');
        set(figno,'BackingStore','off','Visible','on')
        set(0,'CurrentFigure',oldfig);
  end;
else 
    sys = [];
end

