function  [sys, x0]  = sfunplot(t,x,u,flag,figno,ax,ltype)
%SFUNPLOT An improved S-function scope using a user-defined graph window.
%
%	This M-file is designed to be used in a SIMULINK S-function block.
%	It stores the last input point using discrete states 
%       and then plots this against time. A desired figure number can be
%       specified.
%
%       The input arguments are
%       figno:          Figure number.
%       ax:             Axis (4-element vector).
%       ltype:          Color and line type string.

% (c) Robert Babuska, December 1993

if abs(flag) == 2   	% A real time hit 

        figure(figno);

        % If time exceeds X-axis limit
	if t > x(3)
		if x(1) == Inf
			% Initial point
			sys = [t; u; ax(2)];
			return
		end
			
		% Keep track of X-axis limit in third discrete state
		sys = [t; u; x(3)+ax(2)];

		% New axis is the original plus all the elapsed time:
		newax = [ax(1)+x(3),ax(2)+x(3),ax(3),ax(4)]; 
                clf
                axis(newax)
		hold on

		% The y = 0 line
		plot([ax(1),ax(2)],[0,0],'w-.');  % Use dash-dot line

		% Comment out this line if you don't want a grid:
		grid
	else
		% Normally just record previous time and input
		% x(3) remains the same until rescaling.
		sys = [t; u; x(3)];
	end
	% Use none as Erasemode for fast plotting.
        plot([x(1),t], [x(2),u(1)], ltype, 'Erasemode', 'none');

elseif flag  == 0, 	% Initialization

    % [cont, discr, outputs, inputs, roots, feedthrough]
    sys = [0;3;0;1;0;0];

        while ~any(get(0,'Children')==figno),
          figure('Visible','off');
        end
        set(figno,'Visible','off');
        oldfig = get(0,'CurrentFigure');
        set(0,'CurrentFigure',figno);
        set(figno,'BackingStore','off','Visible','on')


	% Initial conditions on states
        x0 = [Inf; Inf; -Inf];  % Infinity flags to indicate first point
	% Initialize graph
	hold off
        clf
        if length(ax) < 4
		disp('Axis not defined correctly; using current axis');
		ax = axis;
	end
	axis(ax)		% Set up the axis
	hold on
	plot(ax(1),ax(3))  	% Force a box to be drawn

	% Comment out this line if you don't want a grid
	grid

        set(0,'CurrentFigure',oldfig);
else 
	% Other flag options not defined.
	sys = [];
end
