function r = impl_pr(a,b,s_norm,t_norm,spar,tpar)
%       R=IMPL_PR(A,B) Propositional calculus implication, by default
%       defined as Zadeh's MAXMIN rule of fuzzy implication
%       R = max(min(Ax, Bx), 1 - Ax).
%
%       R=IMPL_PR(A,B,S_NORM,T_NORM,SPAR,TPAR) General form of propositional
%       calculus implication defined as R = (not A) + (A * B),
%       where + is a triangular co-norm and * is a triangular norm and
%       SPAR and TPAR are parameters for the t norm and co-norm respectively.
%
%       See also IMPL_MA, IMPL_EX

% (c) Robert Babuska, March 1993

a = a(:); b = b(:).';                % make column and row vectors

if (nargin > 3)                         % norms supplied
  if (nargin < 6)                       % params not supplied
      eval(['r = ' s_norm '(not(a),' t_norm '(a'',b));']);
      return
  end;
  eval(['r = ' s_norm '(not(a),' t_norm '(a'',b,tpar),spar);']);
  return
end;

% Otherwise use Zadeh's maxmin rule of fuzzy implication

am = length(a(:,1)); bn = length(b(1,:));
if ( am > 1 & bn > 1 )
    a = a*ones(1,bn); b = ones(am,1)*b;
end;

r = max(min(a,b),1-a);

