function mf = mfequ(dom,mftype,n,t)
% MFEQU Generates equidistant symmetrical membership functions
%
%       MF = MFEQU(DOM,MFTYPE,N,t)
%
%       DOM    - Domain (universe of discourse) defined by four numbers 
%        [mindom lshoulder rshoulder maxdom]
%       MFTYPE - Type of membership functions (see MEMFUN)
%       N      - Number of membership functions or center vector
%                (e.g. [c1 c2 c3 c4 c5 ...])
%       t      - set to one to generate membership functions
%                with non-singleton cores
%                (e.g. [MFTYPE dom(1) dom(1) c1     c2;
%                       MFTYPE c1     c2     c3     c4;
%                       MFTYPE c3     c4     dom(2) dom(2)])
%

% (c) Robert Babuska, June 1993

if nargin < 4, t = 0; end;

if t == 0,
Amin = min(dom); Amax = max(dom); 
n = n(:);
if length(dom) == 4, 
  Smin = dom(2); Smax = dom(3); 
else
  Smin = Amin; Smax = Amax; 
end;
nn  = length(n);
if (nn == 1)
  if (n == 1)
    mf = [mftype -1e10 0 0 1e10];
    return
  end;
  c = Smin*ones(n,1) + (Smax - Smin)/(n-1)*(0:n-1)';
else
  c = sort(n);
  n = nn;
  Smin = min(c); Smax = max(c);
end;
c1 = [Amin; Smin; c(2:n-1)];
c2 = [Amin; c(2:n-1); Smax];
c3 = [Smin; c(2:n-1); Amax];
c4 = [c(2:n-1); Smax; Amax];
if max(size(mftype)) == 1, mftype = mftype*ones(n,1); end;
mf = [mftype(:) c1 c2 c3 c4];

elseif t == 1,
   c = zeros(2,length(n)/2);
   c(:) = n;
   c = vertcat(c,c);
   c = [min(dom); min(dom); c(:); max(dom); max(dom)];
   c = reshape(c,4,length(c)/4)';
   if max(size(mftype)) == 1, mftype = mftype*ones(size(c,1),1); end;
   mf = [mftype(:) c];
end;
