function c=or_pr(a,b)
%       C=OR_PR(A,B) The union (probabilistic sum) of two
%       fuzzy sets A and B defined as OR_PR(A,B) = Ax + Bx - Ax*Bx.
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A + B, where
%       + is Ax + Bx - Ax*Bx.
%
%       C = OR_PR(A) calculates union of all rows in A.
%
%       See also OR, OR_ZA, OR_LU, OR_RE.

% (c) Robert Babuska, March 1993

[am,an] = size(a);
if nargin == 2,
  [bm,bn] = size(b);
  if ( am > 1 & an == 1 & bn > 1 )
    a = a * ones(1,bn);
    if ( bm == 1 )
        b = ones(am,1) * b;
    end;
  end;
  c = a + b - a.*b;
else
  c = a(1,:);
  for i = 2 : am,
    c = a(i,:) + c - a(i,:).*c;
  end;
end;

