function c=or_za(a,b)
%       C=OR_ZA(A,B) The union of two fuzzy sets A and B
%       defined as OR_ZA(A,B) = max(Ax,Bx).
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A * B, where * is max.
%
%       C = OR_ZA(A) calculates union of all rows in A.
%
%       See also OR, OR_LU, OR_PR, OR_RE.

% (c) Robert Babuska, March 1993

if nargin == 2,
  [am,an] = size(a); [bm,bn] = size(b);
  if ( am > 1 & an == 1 & bn > 1 )
    a = a * ones(1,bn);
    if ( bm == 1 )
        b = ones(am,1) * b;
    end;
  end;
  c=max(a,b);
else
  c = max(a);
end;

