function txt = rlslog(x,rls,dof,inputs,outputs,nlab,labels,filename,mode);
% RLS2TXT writes the rule base coded in a matrix into a string
% or file. TXT = RLS2TXT(X,RLS,DOF,INPUTS, OUTPUTS, NLAB, LABELS,FILENAME,MODE)
%
% Inputs:     X		...  input matrix (vector)
%	      RLS       ...  rule-base matrix
%	      DOF	...  degree-of-fulfillment matrix (vector)
%             INPUTS    ...  input labels
%             OUTPUTS   ...  output labels
%             NLAB      ...  number of labels for all inputs and outputs
%                            i.e. [i1; i2; i3; ... o1; o2; ...]
%             LABELS    ...  input and output labels concatenated in one
%                            matrix, i.e. [Input1_Label1; Input1_Label2;
%                                                       ...
%                                          Input2_Label1; Input2_Label2;
%                                                       ...
%                                          Output1_Label1; Output1_Label2;
%                                                       ...               ]
%             FILENAME  ...  file name (optional)
%	      MODE      ...  file write mode ('w' - write, 'a' - append)
%			     'w' is default
% Output:     TXT       ...  text matrix
%
% See also TXT2RLS, RLS2TXT, SAMPLE.RB, MFSET, MFGET, INFER

% (c) Robert Babuska, November 1994


% directives and keywords
IfStr   = ' If '; ThenStr = ' then '; IsStr   = ' is ';
AndStr  = ' and '; NotStr  = ' not '; RuleEnd = '; ';
CSepStr = ', ';

if nargin < 9, mode = 'w'; end;
[ninps,dummy] = size(inputs);
rls(:,1) = [];
[nrules,nio] = size(rls);
[nrules,dummy] = size(dof);
nouts = nio - ninps;
nlab = nlab(:);
for i = 1 : ninps, ipos(i) = length(deblank(inputs(i,:))); end;

headstr = [];
for i = 1 : ninps, headstr = [headstr sprintf(['%' num2str(max(ipos(i),6)) 's'],deblank(inputs(i,:))) '  ']; end;
headstr = [headstr '   DOF     #   rule'];
txt = [];
for r = 1 : nrules,
  jnd = find(dof(r,:) > 0);
  for k = jnd,
   rule = IfStr;
    j = 0;
    for i = 1 : ninps
      if rls(k,i) ~= 0,
        j = j + 1;
        if j > 1, rule = [rule AndStr]; end;
        if rls(k,i) < 0; label = [NotStr labels(abs(rls(k,i)),:)];
        else label = labels(rls(k,i),:); end;
        rule = [rule inputs(i,:) IsStr label];
      end;
      if i == ninps, rule = [rule ThenStr]; end;
    end;
    j = 0;
    for i = 1 : nouts
      if rls(k,ninps+i) ~= 0 | nlab(ninps+i) == 0,
        j = j + 1;
        if j > 1, rule = [rule(1:length(rule)-1) CSepStr]; end;
        if nlab(ninps+i) ~= 0, cons = labels(rls(k,ninps+i),:);
        else cons = sprintf('%f',rls(k,ninps+i)); end;
        rule = [rule outputs(i,:) IsStr cons ' '];
      end;
    end;
    ind = find(rule == ' ');
    li = length(ind);
    rule(ind(find(ind(2:li)-ind(1:li-1) == 1))) = [];   % remove multiple blanks

    rule = [sprintf('   %-4.2f',dof(r,k)) ' ' sprintf('   %-3.0f',k) rule];
    for i = ninps : -1 : 1,
      if k == jnd(1),
        rule = [sprintf(['%' num2str(max(ipos(i),6)) '.2f  '],x(r,i)) rule];
      else 
        rule = [sprintf(['%' num2str(max(ipos(i),6)) 's  '],' ') rule];
      end;
    end;
    txt = str2mat(txt,rule);
  end;
% txt = str2mat(txt,'');
end;
if nargin > 7,
  filefound = exist(filename) == 2;
  fid = fopen(filename,mode);
  if fid == -1, error(['Error opening file ' filename]); end;
  if ~filefound | mode == 'w',
    fprintf(fid,'%s\n',headstr);
    fprintf(fid,'%s\n',setstr(abs('=')*ones(1,size(txt,2))));
  end;
  for i = 2 : size(txt,1),
    fprintf(fid,'%s\n',deblank(txt(i,:)));
  end;
  fclose(fid);
end;

txt = str2mat(headstr,setstr(abs('=')*ones(1,size(txt,2))),txt(2:size(txt,1),:));

