function c=t_fr(a,b,w)
%       C=T_FR(A,B,W) The t-norm proposed by Frank.
%       W is from (0,+inf) and W <> 1.
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A x B.
%
%       T_FR(A,W) calculates the t-norm between all rows in A.
%       In this case, W can be a vector of parameters.
%
%       See also TNORM, T_DU, T_LA, T_YA, T_DO, T_HA, T_SK.

% (c) Robert Babuska, March 1993

am = size(a,1); bn = size(b,2);
if nargin == 3,
  if ( am > 1 & bn > 1 )
    a=a*ones(1,bn); b=ones(am,1)*b;
  end;
  c = log(1 + 1/(w-1) .* (w.^a - 1) .* (w.^b - 1))/log(w);
else
    for j = length(b) : -1 : 1,
      c(j,:) = a(1,:);
      for i = 2 : am,
        c(j,:) = log(1 + 1/(b(j)-1) .* (b(j).^a(i,:) - 1) .* (b(j).^c(j,:) - 1))/log(b(j));
      end;
    end;
end;
