function d = dist(x,v)
% DIST calculates distance of data points X from centers V. Used by
%      FISODATA.
%
% D = DIST(X,V)
%    Input:
%       X ... M by N data matrix, M number of data points
%             and N the X vector dimension
%       V ... C by N matrix defining C centers in
%             N-dimensional space
%    Output:
%       D ... M by C matrix, each element d(i,j) is the Euclidean
%             distance |x(i) - v(j)|

% (c) Robert Babuska, June 1993

[mx,nx] = size(x);
[mv,nv] = size(v);
if (nx == 1)
  d = abs(x*ones(1,mv) - ones(mx,1)*v');
else
  d = zeros(mx,mv);
  for i = 1 : mv
      d(:,i) = sqrt(sum((x - ones(mx,1)*v(i,:))'.^2)');
  end;
end;

